@@ -1,10 +1,12 @@
+#include <Eigen/Core>
 #include <pybind11/pybind11.h>
 #include <pybind11/numpy.h>
 #include <pybind11/eigen.h>
 #include <pybind11/stl.h>
 #include <cmath>
 #include <vector>
-#include <Eigen/Core>
+#include <boost/math/special_functions/gamma.hpp>
+
 
 namespace py = pybind11;
 
@@ -310,11 +312,9 @@ Eigen::VectorXd pdf_clayton(
     Eigen::VectorXd res(u_values.rows());
     double d = float(u_values.cols());
     Eigen::VectorXd lu = u_values.array().log().matrix().rowwise().sum();
-    Eigen::VectorXd t_var = ipsi_clayton(
-        u_values, theta, false
-    ).rowwise().sum();
+    Eigen::VectorXd t_var = ipsi_clayton(u_values, theta, false).rowwise().sum();
     if(theta < 0.0){
-        for(auto i = 0.0; i < u_values.rows(); i++){
+        for(auto i = 0; i < u_values.rows(); i++){
             if(t_var(i) < 1.0){
                 res(i) = std::log1p(theta);
                 res(i) -= (1.0 + theta) * lu(i);
@@ -386,6 +386,7 @@ py::array_t<double> ipsi_gumbel_py(
     );
 }
 
+
 double fact(double n) {
    if ((n==0.0)||(n==1.0))
    return 1.0;
@@ -393,6 +394,7 @@ double fact(double n) {
    return n*fact(n-1.0);
 }
 
+
 int fact(int n) {
    if ((n==0)||(n==1))
    return 1;
@@ -400,12 +402,40 @@ int fact(int n) {
    return n*fact(n-1);
 }
 
-double poisscdf(int x, double lambda){
-    double res = 0.0;
-    for(int i = 0; i <= int(std::floor(x)); i++){
-        res += std::pow(lambda, double(i)) / fact(i);
+
+double log_poisscdf(double k, double lambda){
+    return std::log(boost::math::gamma_q(k + 1.0, lambda));
+}
+
+
+Eigen::MatrixXd lpoiss_check(
+    Eigen::VectorXd lx_var,
+    double alpha_var,
+    int d_var){
+    Eigen::VectorXd k = Eigen::VectorXd::LinSpaced(d_var, 1.0, double(d_var));
+    Eigen::VectorXd x = lx_var.array().exp();
+    Eigen::MatrixXd lppois = Eigen::MatrixXd::Zero(d_var, lx_var.size());
+    for(auto row = 0; row < d_var; row++){
+        for(auto col = 0; col < lx_var.size(); col++){
+            lppois(row, col) = log_poisscdf(double(d_var) - k(row), x(col));
+        }
     }
-    return std::exp(-lambda) * res;
+    return lppois;
+}
+
+
+py::array_t<double> lpoiss_check_py(
+    py::array_t<double> lx_var,
+    double alpha_var,
+    int d_var
+){
+    return py::cast(
+        lpoiss_check(
+            lx_var.cast<Eigen::Matrix<double, 1, Eigen::Dynamic>>(),
+            alpha_var,
+            d_var
+        )
+    );
 }
 
 
@@ -425,11 +455,13 @@ Eigen::VectorXd lsum_row(
         b_i = x_values.array().log().matrix();
     }
     Eigen::VectorXd b_max = b_i.colwise().maxCoeff();
+    Eigen::VectorXd res = Eigen::VectorXd::Zero(b_i.cols());
     for(auto row = 0; row < x_values.rows(); row++){
-        b_i.block(row, 0, 1, x_values.cols()) -= b_max.transpose();
+        for(auto col = 0; col < x_values.cols(); col++){
+            b_i(row, col) = std::exp(b_i(row, col) - b_max(col));
+            res(col) += b_i(row, col);
+        }
     }
-    b_i = b_i.array().exp().matrix();
-    Eigen::VectorXd res = b_i.colwise().sum();
     res = res.array().log();
     return b_max + res;
 }
@@ -451,11 +483,13 @@ Eigen::VectorXd lsum_col(
         b_i = x_values.array().log().matrix();
     }
     Eigen::VectorXd b_max = b_i.rowwise().maxCoeff();
+    Eigen::VectorXd res = Eigen::VectorXd::Zero(b_i.rows());
     for(auto col = 0; col < x_values.cols(); col++){
-        b_i.block(0, col, x_values.rows(), 1) -= b_max;
+        for(auto row = 0; row < x_values.rows(); row++){
+            b_i(row, col) = std::exp(b_i(row, col) - b_max(row));
+            res(row) += b_i(row, col);
+        }
     }
-    b_i = b_i.array().exp().matrix();
-    Eigen::VectorXd res = b_i.rowwise().sum();
     res = res.array().log();
     return b_max + res;
 }
@@ -463,8 +497,8 @@ Eigen::VectorXd lsum_col(
 
 py::array_t<double> lsum_py(
     py::array_t<double> x_values,
-    int axis = 0,
-    bool is_log = true
+    bool is_log = true,
+    int axis = 0
 ){
     if(axis == 0){
         return py::cast(
@@ -490,7 +524,7 @@ py::array_t<double> lsum_py(
 }
 
 
-Eigen::VectorXd llsum(
+Eigen::VectorXd lssum(
     Eigen::Matrix<
         double,
         Eigen::Dynamic,
@@ -518,13 +552,13 @@ Eigen::VectorXd llsum(
 }
 
 
-py::array_t<double> llsum_py(
+py::array_t<double> lssum_py(
     py::array_t<double> x_values,
     py::array_t<double> x_sign,
     bool is_log = true
 ){
     return py::cast(
-        llsum(
+        lssum(
             x_values.cast<Eigen::Matrix<
                 double,
                 Eigen::Dynamic,
@@ -596,7 +630,7 @@ Eigen::VectorXd log_polyg(
     Eigen::MatrixXd lppois = Eigen::MatrixXd::Zero(d_var, lx_var.size());
     for(auto row = 0; row < d_var; row++){
         for(auto col = 0; col < lx_var.size(); col++){
-            lppois(row, col) = std::log(poisscdf(d_var - k(row), x(col)));
+            lppois(row, col) = log_poisscdf(double(d_var) - k(row), x(col));
         }
     }
     Eigen::MatrixXd llx = k * lx_var.transpose();
@@ -617,7 +651,7 @@ Eigen::VectorXd log_polyg(
             ) + x(col);
         }
     }
-    return llsum(lxabs, signff(alpha_var, k, d_var), true);
+    return lssum(lxabs, signff(alpha_var, k, d_var), true);
 }
 
 
@@ -795,7 +829,7 @@ PYBIND11_MODULE(c_archimedean, m) {
     )pbdoc",
     py::arg("x_values"), py::arg("axis"), py::arg("is_log"));
 
-    m.def("llsum", &llsum_py, R"pbdoc(
+    m.def("lssum", &lssum_py, R"pbdoc(
         :param x_values: np.array
         :param x_sign: np.array
         :param is_log: bool
@@ -819,6 +853,14 @@ PYBIND11_MODULE(c_archimedean, m) {
     )pbdoc",
     py::arg("lx_var"), py::arg("alpha_var"), py::arg("d_var"));
 
+    m.def("lpoiss_check", &lpoiss_check_py, R"pbdoc(
+        :param lx_var: np.array
+        :param alpha_var: double
+        :param d_var: double
+        :return:
+    )pbdoc",
+    py::arg("lx_var"), py::arg("alpha_var"), py::arg("d_var"));
+
     m.def("pdf_gumbel", &pdf_gumbel, R"pbdoc(
         :param u_values: np.array
         :param theta: double
@@ -826,10 +868,4 @@ PYBIND11_MODULE(c_archimedean, m) {
         :return:
     )pbdoc",
     py::arg("u_values"), py::arg("theta"), py::arg("is_log"));
-
-#ifdef VERSION_INFO
-    m.attr("__version__") = VERSION_INFO;
-#else
-    m.attr("__version__") = "dev";
-#endif
 }
