@@ -96,7 +96,7 @@ def sim_m_samples(n_value, m_sample,
     spurious = sim_multivariate_gaussian(n_value=n_value,
                                          m_sample=m_sample,
                                          theta=theta_0)
-    k_state = list()
+    k_state = []
     for i in range(int(n_value)):
         k_state.append(True)
         if not bool(bernoulli.rvs(p=theta_1['pi'], size=1)):
@@ -377,7 +377,7 @@ def m_step_rho(z_values, k_state, theta):
         z_norm_time_i = 0.0
         for j in range(z_values.shape[1]):
             for k in range(z_values.shape[1]):
-                if not k == j:
+                if k != j:
                     z_norm_time_i += (float(z_values[i][j]) -
                                       float(theta['mu'])) * \
                                      (float(z_values[i][k]) - float(
@@ -424,10 +424,10 @@ def delta(theta_t0, theta_t1, threshold, logl):
     """
     if logl == -np.inf:
         return True
-    for parameters in theta_t0:
-        if abs(theta_t0[parameters] - theta_t1[parameters]) > threshold:
-            return True
-    return False
+    return any(
+        abs(theta_t0[parameters] - theta_t1[parameters]) > threshold
+        for parameters in theta_t0
+    )
 
 
 def em_pseudo_data(z_values,
