@@ -113,17 +113,12 @@ def readbeds(bed_paths: list,
     :param sort_cols: list of columns to sort the pd.DataFrame on
     :return: list of pd.DataFrame
     """
-    bed_files = list()
-    for bed_path in bed_paths:
-        bed_files.append(
-            sort_bed(
+    return [sort_bed(
                 bed_file=readbed(
                     bed_path=bed_path,
                     bed_cols=bed_cols),
                 sort_cols=sort_cols
-            )
-        )
-    return bed_files
+            ) for bed_path in bed_paths]
 
 
 def readfiles(file_names: list,
@@ -150,9 +145,7 @@ def readfiles(file_names: list,
     :return: list[pd.DataFrame] containing the file csv columns
     """
     log.logging.info("%s", "reading bed files")
-    bed_paths = list()
-    for file_name in file_names:
-        bed_paths.append(PurePath(file_name))
+    bed_paths = [PurePath(file_name) for file_name in file_names]
     return merge_beds(
         bed_files=readbeds(
             bed_paths=bed_paths,
@@ -250,9 +243,7 @@ def pos_overlap(pos_ref: pd.Series, pos: pd.Series) -> bool:
     if pos_ref['start'] > pos['stop']:
         return False
     # pos after pos_ref
-    if pos_ref['stop'] < pos['start']:
-        return False
-    return True
+    return pos_ref['stop'] >= pos['start']
 
 
 def best_peak(ref_peak: pd.Series, peaks: pd.DataFrame,
@@ -741,14 +732,13 @@ def merge_beds(bed_files: list,
         )
     nan_pos = set(nan_pos)
     log.logging.info("%s", str(len(nan_pos)) + " peaks unmached")
-    if drop_unmatched:
-        for merged in range(len(merged_files)):
+    for merged in range(len(merged_files)):
+        if drop_unmatched:
             merged_files[merged] = expand_peaks(
                 merged_files[merged].drop(nan_pos),
                 size=-size
             )
-    else:
-        for merged in range(len(merged_files)):
+        else:
             merged_files[merged] = expand_peaks(
                 merged_files[merged].fillna(0.0),
                 size=-size
@@ -778,7 +768,7 @@ def narrowpeaks2array(np_list: list,
            [20, 21, 22],
            [10, 11, 12]])
     """
-    scores = list()
+    scores = []
     for np_file in np_list:
         scores.append(np.array(np_file[score_cols].to_numpy()))
     scores = np.stack(scores, axis=-1)
