@@ -137,16 +137,12 @@ def list_of_u_values(u_values, missing=None):
     ... )
     array([0, 1, 0, 0, 2, 0, 0, 1, 0, 0])
     """
-    list_u_values = list()
     nb_missing_row = number_of_missing(u_values=u_values, missing=missing)
-    for nb_missing in range(u_values.shape[1]):
-        list_u_values.append(
-            remove_missing(
+    list_u_values = [remove_missing(
                 u_values=u_values[nb_missing_row == nb_missing, :],
                 missing=missing,
                 nb_missing=nb_missing
-            )
-        )
+            ) for nb_missing in range(u_values.shape[1])]
     return (nb_missing_row, list_u_values)
 
 
@@ -301,9 +297,11 @@ def delta(params_list, threshold):
     ... )
     False
     """
-    max_delta = list()
-    max_delta.append(max(abs(params_list['alpha'] - params_list['alpha_old'])))
-    max_delta.append(abs(params_list['pi'] - params_list['pi_old']))
+    max_delta = [
+        max(abs(params_list['alpha'] - params_list['alpha_old'])),
+        abs(params_list['pi'] - params_list['pi_old']),
+    ]
+
     for copula in copula_names():
         max_delta.append(
             abs(params_list[copula]['theta'] - params_list[copula]['theta_old'])
@@ -913,8 +911,7 @@ def samic(x_score, threshold=1e-4, missing=None):
         gaussian=True,
         missing=missing
     )
-    params_list = dict()
-    params_list['order'] = dict()
+    params_list = {'order': {}}
     i = 0
     for copula in copula_names():
         if missing is None:
